# TTRPG-Core

[![PyPI - Version](https://img.shields.io/pypi/v/ttrpg-core.svg)](https://pypi.org/project/ttrpg-core)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/ttrpg-core.svg)](https://pypi.org/project/ttrpg-core)

-----

**Table of Contents**

- [TTRPG-Core](#ttrpg-core)
  - [Installation](#installation)
  - [License](#license)

## Installation

```console
pip install ttrpg-core
```

## License

`ttrpg-core` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.